==> aria2_1.4.1.orig.tar.gz: aria2-1.4.1/src/DHTInteractionCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DHT_INTERACTION_COMMAND_H_
#define _D_DHT_INTERACTION_COMMAND_H_

#include "Command.h"
#include "SharedHandle.h"

namespace aria2 {

class DHTMessageDispatcher;
class DHTMessageReceiver;
class DHTTaskQueue;
class DownloadEngine;
class SocketCore;

class DHTInteractionCommand:public Command {
protected:
  DownloadEngine* _e;
private:
  SharedHandle<DHTMessageDispatcher> _dispatcher;
  SharedHandle<DHTMessageReceiver> _receiver;
  SharedHandle<DHTTaskQueue> _taskQueue;
  SharedHandle<SocketCore> _readCheckSocket;

public:
  DHTInteractionCommand(int32_t cuid, DownloadEngine* e);

  virtual ~DHTInteractionCommand();

  virtual bool execute();

  void setReadCheckSocket(const SharedHandle<SocketCore>& socket);

  void disableReadCheckSocket(const SharedHandle<SocketCore>& socket);

  void setMessageDispatcher(const SharedHandle<DHTMessageDispatcher>& dispatcher);

  void setMessageReceiver(const SharedHandle<DHTMessageReceiver>& receiver);

  void setTaskQueue(const SharedHandle<DHTTaskQueue>& taskQueue);
};

} // namespace aria2

#endif // _D_DHT_INTERACTION_COMMAND_H_

==> aria2-1.17.1.tar.gz: aria2-1.17.1/src/DHTInteractionCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_DHT_INTERACTION_COMMAND_H
#define D_DHT_INTERACTION_COMMAND_H

#include "Command.h"
#include "SharedHandle.h"

namespace aria2 {

class DHTMessageDispatcher;
class DHTMessageReceiver;
class DHTTaskQueue;
class DownloadEngine;
class SocketCore;
class DHTConnection;
class UDPTrackerClient;

class DHTInteractionCommand:public Command {
private:
  DownloadEngine* e_;
  SharedHandle<DHTMessageDispatcher> dispatcher_;
  SharedHandle<DHTMessageReceiver> receiver_;
  SharedHandle<DHTTaskQueue> taskQueue_;
  SharedHandle<SocketCore> readCheckSocket_;
  SharedHandle<DHTConnection> connection_;
  SharedHandle<UDPTrackerClient> udpTrackerClient_;
public:
  DHTInteractionCommand(cuid_t cuid, DownloadEngine* e);

  virtual ~DHTInteractionCommand();

  virtual bool execute();

  void setReadCheckSocket(const SharedHandle<SocketCore>& socket);

  void disableReadCheckSocket(const SharedHandle<SocketCore>& socket);

  void setMessageDispatcher(const SharedHandle<DHTMessageDispatcher>& dispatcher);

  void setMessageReceiver(const SharedHandle<DHTMessageReceiver>& receiver);

  void setTaskQueue(const SharedHandle<DHTTaskQueue>& taskQueue);

  void setConnection(const SharedHandle<DHTConnection>& connection);

  void setUDPTrackerClient
  (const SharedHandle<UDPTrackerClient>& udpTrackerClient);
};

} // namespace aria2

#endif // D_DHT_INTERACTION_COMMAND_H
